| corARMA | R Documentation |
Re-exports nlme::corARMA from the nlme package.
corARMA(value, form, p, q, fixed)
value |
numeric vector of parameter values |
form |
a one-sided formula of the form |
p |
non-negative integer specifying the autoregressive order |
q |
non-negative integer specifying the moving average order |
fixed |
unused |
In the original nlme::corARMA function, a covariate t must be an integer class.
In pwr4exp, t can also be a factor class, which is then converted to an integer internally for chronological order.
The class of t in the model formula, if present, is not converted. For example, a time covariate can be fitted as a factor
in the model formula, whereas it is converted to an integer in the correlation formula.
corClasses See nlme::corARMA for original documentation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.