| findbars | R Documentation |
Determine random-effects expressions from a formula
findbars(term)
term |
a mixed-model formula |
pairs of expressions that were separated by vertical bars
This function is called recursively on individual
terms in the model, which is why the argument is called term and not
a name like form, indicating a formula.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.