Residual Variance-Covariance Matrices
mkRTrms(data, correlation = NULL)A list containing:
corStruct: An initialized correlation structure.
corframe: A processed data frame with indexed grouping variables and ordering for correlation structures.
R: A block-diagonal residual variance-covariance structure, not yet scaled by the residual variance
a data frame with grouping factors and covariates.
a corStruct object created by corClasses functions.
If NULL, an identity matrix is assumed.