Re-exports nlme::corAR1 from the nlme package.
corAR1(value, form, fixed)numeric value for the correlation parameter.
a one-sided formula of the form ~ t, ~ 1 | g, or ~ t | g,
specifying a time covariate t, a grouping factor g, or both.
When no time covariate is specified, the row order of the data within each group is assumed to
represent the chronological order of measurements.
unused
In the original nlme::corAR1 function, a covariate t must be an integer class.
In pwr4exp, t can also be a factor class, which is then converted to an integer internally for chronological order.
The class of t in the model formula, if present, is not converted. For example, a time covariate can be fitted as a factor
in the model formula, whereas it is converted to an integer in the correlation formula.
corClasses See nlme::corAR1 for original documentation.